@@ -2,12 +2,8 @@ use std::collections::HashSet;
 
 fn main() {
     // Get the stop words
-
     let vec = stop_words::get(stop_words::LANGUAGE::English);
-    let set: HashSet<String> = vec.into_iter().collect();
 
-    // Print them
-    for word in set {
-        println!("{}", word)
-    }
+    // Convert to hash set
+    let _set: HashSet<String> = vec.into_iter().collect();
 }
